* ********************************************************************************************
* ********************************************************************************************
* 					REPLICATION FILE FOR
*
* Walter, Stefanie (fortcoming). Globalization and the Welfare State. Testing the Microfoundations
*         of the Compensation Hypothesis. International Studies Quarterly
*
* ********************************************************************************************
* ********************************************************************************************
* Stefanie Walter, 25.5.2009


* This do-file contains the STATA-code for replicating the coding and the analyses in 
* Stefanie Walter's 2010 ISQ paper on the microfoundations of the compensation hypothesis.

* Basis for the analysis is the 2007 World Values Survey (WVS) in Switzerland. The data was 
* provided by this wave's prinipal investigators. For additional information and additional analyses see

* Hug, Simon and Hanspeter Kriesi (XXXX): Value Change in Switzerland.



/* ----------------------------------------------------------------------------
* 								TABLE OF CONTENTS
* ----------------------------------------------------------------------------

* 1. RECODING
* 	1.1 Independent Variables
* 		1.1.1 Trade 
*		1.1.2 FDI
* 		1.1.3 Offshoreability
* 		1.1.4 Skills (education)
* 		1.1.5 Interaction Terms
*	1.2 Dependent Variables
*		1.2.1 Economic Insecurity
*		1.2.2 Demands for Compensation (Social Policy Preference)
*		1.2.3 Partsan Preference for the Left (Social Democratic Party)
*	1.3	Control Variables
*		1.3.1 Income
*		1.3.2 Gender
*		1.3.3 Age
*		1.3.4 Labor Union Membership
*		1.3.5 Sectoral Unemployment Rate
*		1.3.6 Risk Aversion
*		1.3.7 Opinion on Swiss EU-Membership
*		1.3.8 Public Sector Employee
*	1.4 Drop Pensioners and Foreigners
	
* 2. DESCRIPTIVES
*	2.1 Descriptive Statistics
* 	2.2 Comparison of sample vs. aggregate employment percentages (Tables A1-A3, Appendix)
*		2.2.1 Trade (Table A1)
*		2.2.2 FDI (Table A2)
*		2.2.3 Offshoreabilty (Table A3)

* 3. REPLICATION OF REGRESSION ANALYSES
* 	3.1 LINK 1: Globalization and Economic Insecurity (Table 1 and 2)
*		3.1.1 Trade
*		3.1.2 FDI
* 		3.1.3 Offshoreability		
*		3.1.4 Make Table 1a
* 	3.2 LINK 2: Globalization, Economic Insecurity, and Demands for Social Protection (Table 1 and 2 ctd.)
*		3.2.1 Economic Insecurity
*		3.2.2 Trade
*		3.2.3 FDI
* 		3.2.4 Offshoreability		
*		3.2.5 Make Table 1b
* 	3.3 LINK 3: Globalization, Demands for Social Protection, and Party Preference (Table 2 and 3) 
*		3.3.1 Demands for Social Protection
*		3.3.2 Trade
*		3.3.3 FDI
* 		3.3.4 Offshoreability		
*		3.3.5 Make Table 3
*/

clear
set mem 1g
use "/Users/steffi/Documents/Papers/abgeschlossene Projekte/2010.ISQ.Compensation/ISQ FINAL/Replication/ISQ REPLICATION/WVS_Switzerland_wave2007.dta"


* ********************************************************************************************
* ******************************		1. RECODING		**************************************
* ********************************************************************************************

* ********************************************************************************************
* 1.1 Independent Variables
* ********************************************************************************************

* ===========================================================================================
* 1.1.1 TRADE
* ===========================================================================================
* This code adds Trade exposure for each respondent in the 2007 WVS wave.
* Trade exposure is measured on the sectoral level. 

* Source: OECD.Stats, downloaded on 26.2.09
* Data are for 2006
* Trade Exposure is measured as (sectoral Exports+Imports/sectoral GDP)

gen tradeexposure=.
label var tradeexposure "Exposure to trade, sectoral [(M+X)/GDP]"

replace tradeexposure=0 if sec07<.
replace tradeexposure=.49899 if sec07==1
replace tradeexposure=.37901 if sec07==2
replace tradeexposure=3.51474 if sec07==3
replace tradeexposure=.70304 if sec07==4
replace tradeexposure=1.49230 if sec07==5
replace tradeexposure=1.31169 if sec07==6
replace tradeexposure=2.64755 if sec07==7
replace tradeexposure=0 if sec07>7 & sec07<14
replace tradeexposure=.00023 if sec07==14
replace tradeexposure=0 if sec07>14 & sec07<18
replace tradeexposure=.00023 if sec07==18
replace tradeexposure=.20812 if sec07==19

* Recode tradeexposure as zero for public employees
gen public=inst07==2
replace public=. if inst07>3
label var public "Public Sector Employee"

replace tradeexposure=0 if public==1


* ===========================================================================================
* 1.1.2 FDI ok
* ===========================================================================================
* This code adds sectoral FDI data to the WVS data, based on the respondent's sector of employment

* Source: Swiss National Bank (2007)  Entwicklung der Direktinvestitionen 2006 (FDI-Daten)
* and Bundesamt fr Statistik (2007): T3a.2 Produktionskonto nach Branchen (sectoral GDP)
* (calculations see FDI-sektoral.xls)

* Note:
* Because of the imperfect match between the FDI data and the sectoral information in the WVS, only
* five different industries can be distinguished

* Outgoing FDI
* ---------------
gen fdi_out=.
label var fdi_out "FDI outgoing (Level) in % of sectoral GDP"
replace fdi_out=194.54 if sec07<9
replace fdi_out=36.41 if sec07==9
replace fdi_out=584.39 if sec07==13
replace fdi_out=18.86 if sec07==11 | sec07==12 | sec07==14
replace fdi_out=7.06 if sec07==10
replace fdi_out=7.06 if sec07>14 &sec07<=20
replace fdi_out= 0.0000001 if inst07==2 // replace public-sector FDI with 0% FDI

gen logfdi_out=log(fdi_out)
label var logfdi_out "% FDI outflows (log)"

* Ingoing FDI
* ---------------
gen fdi_in=.
label var fdi_in "FDI ingoing (Level) in % of sectoral GDP"

replace fdi_in=36.29 if sec07<9
replace fdi_in=58.15 if sec07==9
replace fdi_in=294.37 if sec07==13
replace fdi_in=24.03 if sec07==11 | sec07==12 | sec07==14
replace fdi_in=3.76 if sec07==10
replace fdi_in= 3.76 if sec07>14 &sec07<=20
replace fdi_in= 0.0000001 if inst07==2 // replace public-sector FDI with 0% FDI

gen logfdi_in=log(fdi_in)
label var logfdi_in "% FDI inflows (log)"

* Total FDI (ingoing+outgoing)
* -----------------------------
gen fdi_total=.
label var fdi_total "FDI total (Level) in % d of sectoral GDP"

replace fdi_total=230.83 if sec07<9
replace fdi_total=94.56 if sec07==9
replace fdi_total=878.76 if sec07==13
replace fdi_total=42.89 if sec07==11 | sec07==12 | sec07==14
replace fdi_total=10.82 if sec07==10
replace fdi_total= 10.82 if sec07>14 &sec07<=20
replace fdi_total= 1 if inst07==2  // replace public-sector FDI with 0% FDI


gen logfdi=log(fdi_total)
label var logfdi "% Total FDI (log)"


* ===========================================================================================
* 1.1.3 Offshoreability
* ===========================================================================================
* This code adds Offshoreability-Scores for each respondent in the 2007 WVS wave. 

* The Offshorability-Index was developed by Blinder (2007) and applied to 381 different 
* professions in Switzerland by Muhl (2007). This index measures a jobs potential to be 
* moved abroad. The criterion is whether the service the job provides can be delivered 
* over long distances with little or no degradation in quality. The index ranges from 
* 0 (no offshoring-potential) to 100 (high offshoring potential). 

* To construct this variable, the qualitative job description given by each respondent (Question v242, 
* variables pr_c07 und pro07) is used to assign the value for the corresponding profession in Muhls 
* offshoreability-ranking to each respondent. 

* Note: certain professions have two values in the offshreability-index, in order to account 
*		for the fact that some jobs in this profession are more offshoreable than others.
*		In these cases I used the mean value for this profession.

* Source: Muhl, Patrick (2008): Swiss Issues Konjunktur: Lohnrunde 2008: Was ist zu 
*			erwarten? Zrich: Credit Suisse Economic Research.


gen offshore=.
label var offshore "0ffshoreability-Index 07, 0=min, 100=max (Muhl 2007)"

* pr_c07
replace offshore=	62.5	if pr_c07=="ABTEILUNGSLEITER BEI CEMENTIT"
replace offshore=	.	if pr_c07=="ADDICTOLOGUE"
replace offshore=	39	if pr_c07=="AIUTO ORGANIZZAZIONE MUSEO MAX HUBER"
replace offshore=	25	if pr_c07=="AMMINISTRAZIONE"
replace offshore=	7	if pr_c07=="ANGESTELLTE FREIBAD KASSE"
replace offshore=	39	if pr_c07=="ANGESTELLTER INDUSTRIE"
replace offshore=	46	if pr_c07=="APM THERAPEUTIN"
replace offshore=	50	if pr_c07=="ASSISTENTIN VON PROF. MIKRO BIOLOGIE"
replace offshore=	84	if pr_c07=="AUSSENDIENST"
replace offshore=	84	if pr_c07=="AUSSENDIENST MITARBEITER"
replace offshore=	50	if pr_c07=="BANKSTELLENLEITER"
replace offshore=	62.5	if pr_c07=="BERATER FR QUALITTVERBESSERUNG"
replace offshore=	10	if pr_c07=="BEWEGUNGSPDAGOGIN"
replace offshore=	39	if pr_c07=="BEWERBUNGSASSISTENTIN"
replace offshore=	0	if pr_c07=="CAPO-SETTORE"
replace offshore=	17	if pr_c07=="CHEF D'ENTREPRISE"
replace offshore=	62.5	if pr_c07=="CHEF DE PROJET"
replace offshore=	17	if pr_c07=="CHEF DE SERVICE ESPACE VERT"
replace offshore=	50	if pr_c07=="CHERCHEUSE"
replace offshore=	76	if pr_c07=="CLINICAL RESEARCH"
replace offshore=	7	if pr_c07=="COMMESSA"
replace offshore=	19	if pr_c07=="CONSEILLER TECHNIQUE EN CLIMATISATION"
replace offshore=	77	if pr_c07=="CONSULENTE"
replace offshore=	25	if pr_c07=="COSTRUTTORE PEZZI"
replace offshore=	17	if pr_c07=="DIRECTEUR"
replace offshore=	62.5	if pr_c07=="DIRECTION DE TRAVAUX SECONDE OEUVRE"
replace offshore=	83	if pr_c07=="DIRECTRICE( DESIGNEREIN)"
replace offshore=	17	if pr_c07=="DIREKTOR"
replace offshore=	50	if pr_c07=="DOCTORANTE"
replace offshore=	0	if pr_c07=="DONNE DES COURS PRIVS DE LANGUES ET DE        MATHS"
replace offshore=	10	if pr_c07=="EDUCATORE SPECIALE"
replace offshore=	39	if pr_c07=="EMPLOYE DANS UNE INDUSTRIE ELECTRIQUE"
replace offshore=	0	if pr_c07=="ENSEIGNANT"
replace offshore=	0	if pr_c07=="ENSEIGNANTE"
replace offshore=	0	if pr_c07=="ENSEIGNANTE EN CONOMIE FAMILLIALE"
replace offshore=	62.5	if pr_c07=="ENTREPRENEUR"
replace offshore=	0	if pr_c07=="FACHLEHRER (..RYTHMIE)"
replace offshore=	62.5	if pr_c07=="FONCTIONNAIRE INTERNATIONAL"
replace offshore=	11	if pr_c07=="FONCTIONNAIRE ONU"
replace offshore=	90	if pr_c07=="FORMAZIONE RISORSE PERSONALE"
replace offshore=	11	if pr_c07=="FUNZIONARIO STATALE"
replace offshore=	62.5	if pr_c07=="GEADI- LEITER"
replace offshore=	62.5	if pr_c07=="GESCHFTSBEREICHSLEITER IN EINER IT/ CO"
replace offshore=	17	if pr_c07=="GESCHFTSFHRER"
replace offshore=	11	if pr_c07=="GESCHFTSFHRERIN DER ARBEITSGEMEINSCHA"
replace offshore=	17	if pr_c07=="GESCHFTSINHABERIN"
replace offshore=	17	if pr_c07=="GESCHFTSLEITER"
replace offshore=	17	if pr_c07=="GESTION ASSURANCES"
replace offshore=	10	if pr_c07=="GRUPPEN- LEITER BEHINDERTENWERKSTATT"
replace offshore=	25	if pr_c07=="HANDWERKER MEDIZINISCHE FABRIK KONVENTIONELLE FERTIGUNG"
replace offshore=	0	if pr_c07=="HARFENUNTERRICHT"
replace offshore=	.	if pr_c07=="HAUSFRAU"
replace offshore=	.	if pr_c07=="HAUSFRAU GESCH.FRAU"
replace offshore=	17	if pr_c07=="HOLZBRANCHE SELBSTNDIG"
replace offshore=	0	if pr_c07=="HOSTESS ALL'INFO-POINT"
replace offshore=	76	if pr_c07=="IGENIEUR F&E"
replace offshore=	25	if pr_c07=="IMPIEGATA"
replace offshore=	25	if pr_c07=="IMPIEGATO"
replace offshore=	39	if pr_c07=="IMPIEGATO INDUSTRIA METALCOSTRUZZIONE"
replace offshore=	61	if pr_c07=="IN DER SPEDITION BEI SPIRELLA LOUIS WIDMER KOSMETIKABFLLUNG AN DER MASCHINE"
replace offshore=	17	if pr_c07=="INDIPENDENTE"
replace offshore=	17	if pr_c07=="IND...PENDANTE (PETIT COMMERCE)"
replace offshore=	76	if pr_c07=="INGENIEUR ETS"
replace offshore=	0	if pr_c07=="INSEGNANTE (ATTIVITA CREATIVE)"
replace offshore=	50	if pr_c07=="INSTITUTIONELLES MARKETING UND VERTRIEB BANK"
replace offshore=	0	if pr_c07=="INTENSIV-ABTEILUNGS SCHWESTER"
replace offshore=	62.5	if pr_c07=="KALKULATIONS& AUFTRAGSBEARBEITUNG"
replace offshore=	0	if pr_c07=="LEHRER"
replace offshore=	0	if pr_c07=="LEHRERIN"
replace offshore=	0	if pr_c07=="LEHRPERSON"
replace offshore=	2	if pr_c07=="LEITER INFORMATIKZENTRUM"
replace offshore=	90	if pr_c07=="LEITERIN PR"
replace offshore=	1	if pr_c07=="LEITERIN REINIGUNGSDIENST"
replace offshore=	0	if pr_c07=="MAITRAISE D'ECOLE"
replace offshore=	50	if pr_c07=="MANAGEMENT IN EINER BANK"
replace offshore=	62.5	if pr_c07=="MANAGER INT. SPORTFERNSEHEN"
replace offshore=	62.5	if pr_c07=="MANAGERERIN"
replace offshore=	53	if pr_c07=="MARKETING"
replace offshore=	61	if pr_c07=="MASCHINIST, WSCHER VON KISTLI"
replace offshore=	39	if pr_c07=="MEDECINE"
replace offshore=	39	if pr_c07=="OFFICE MANAGER"
replace offshore=	39	if pr_c07=="OFFICEANGESTELLTE"
replace offshore=	61	if pr_c07=="OPERAIA"
replace offshore=	61	if pr_c07=="OPERAIO GENERICO"
replace offshore=	100	if pr_c07=="OPERATRICE CALLCENTER"
replace offshore=	0	if pr_c07=="OPERTIONSSCHWESTER"
replace offshore=	61	if pr_c07=="OUVRIER DE FABRIQUE"
replace offshore=	61	if pr_c07=="OUVRIRE"
replace offshore=	61	if pr_c07=="OUVRIRE D'USINE"
replace offshore=	61	if pr_c07=="OUVRIRE"
replace offshore=	61	if pr_c07=="OUVRIRE D'USINE"
replace offshore=	17	if pr_c07=="PARTNER BEI ERNSTY YOURG"
replace offshore=	0	if pr_c07=="PATIENTEN DISPONENTIN SPITAL"
replace offshore=	51	if pr_c07=="PERSONALWESEN"
replace offshore=	51	if pr_c07=="PERSONNAGE"
replace offshore=	53.5	if pr_c07=="POLITIK BERATERIN"
replace offshore=	41	if pr_c07=="PREPARATRICE"
replace offshore=	25	if pr_c07=="PROFESSEUR HEP"
replace offshore=	62.5	if pr_c07=="PROJEKT LEITER"
replace offshore=	84	if pr_c07=="PROJEKT- KONTROLLER"
replace offshore=	62.5	if pr_c07=="PROJEKTLEITER"
replace offshore=	25	if pr_c07=="PROJEKTLEITER ARCHITEKTURBRO"
replace offshore=	39	if pr_c07=="PROJEKTMITARBEITER IN DER TELEKOMMUNIKATIONSBRNCHE"
replace offshore=	39	if pr_c07=="PROJEKTSACHBEARBEITERIN"
replace offshore=	84	if pr_c07=="PROKURIST"
replace offshore=	17	if pr_c07=="PROPRITAIRE D'UN KIOSQUE / STAND"
replace offshore=	39	if pr_c07=="PROZESS OPERATUER"
replace offshore=	7	if pr_c07=="PRSIDENT EINER FREIKIRCHE"
replace offshore=	50	if pr_c07=="REGLEUSE"
replace offshore=	47	if pr_c07=="REINIGUNGS UND BAUSTOFFPRFER"
replace offshore=	62	if pr_c07=="RESPONSABILE REVISIONI INTERNE"
replace offshore=	11	if pr_c07=="RESPONSABLE D'UN CENTRE DE REQURANTS D"
replace offshore=	39	if pr_c07=="R RESPONSABLE DES OPRATIONS ARIENNES"
replace offshore=	76	if pr_c07=="RICERCATORE"
replace offshore=	25	if pr_c07=="RPARATEUR + VENDEUR MACHINES  CAF"
replace offshore=	39	if pr_c07=="SACHBEARBEITER"
replace offshore=	39	if pr_c07=="SACHBEARBEITERIN"
replace offshore=	39	if pr_c07=="SACHBEARBEITERIN ( BEZIRKSLEITERIN FRHZUSTELLENUG )"
replace offshore=	39	if pr_c07=="SACHBEARBEITERIN MEDIENSTELLE"
replace offshore=	23	if pr_c07=="SAMMLUNGSTECHNIKER ( ARCHEOLOGIE)"
replace offshore=	25	if pr_c07=="SCHLESSELDIENST"
replace offshore=	71	if pr_c07=="SCHNITTTECHNIKER TEXTILBRANCHE"
replace offshore=	76	if pr_c07=="SCIENTIFICO"
replace offshore=	76	if pr_c07=="SECURITY ENGINEER"
replace offshore=	91	if pr_c07=="SEKRETARIAT UND BILDBEARBEITUNG"
replace offshore=	17	if pr_c07=="SELBSTNDIG"
replace offshore=	.	if pr_c07=="SELE"
replace offshore=	62.5	if pr_c07=="SENIOR ROYALTIER ADMINISTRATOR"
replace offshore=	7	if pr_c07=="SPCIALISTE CAF (NESPRESSO)"
replace offshore=	62.5	if pr_c07=="STABSABTEILUNG (EC-OFFICE) MANAGEMENTPOSITION"
replace offshore=	2	if pr_c07=="TAXIBETRIEB"
replace offshore=	100	if pr_c07=="TELEFONISTIN"
replace offshore=	77	if pr_c07=="TREUHAND/WIRTSCHAFTSKONSULENT"
replace offshore=	17	if pr_c07=="UNTERNEHMENS INHABER"
replace offshore=	11	if pr_c07=="VERTRAGSAUSHANDLUNGEN MIT FFENTLICHEN KRPERSCHAFTEN"
replace offshore=	11	if pr_c07=="VERWALTERIN LOTTERIEFONDS BS"


* pro07
replace offshore=0 if pro07 =="Abwart"
replace offshore=0	if pro07 =="Abwartgehilfe"
replace offshore=0	if pro07 =="Ansthesiepfleger"
replace offshore=	0	if pro07 =="Arztgehilf"
replace offshore=	0	if pro07 =="Arztsekretr"
replace offshore=	0	if pro07 =="Baumschulist"
replace offshore=	0	if pro07 =="Bautenreiniger"
replace offshore=	0	if pro07 =="Berufsfeuerwehrmann"
replace offshore=	0	if pro07 =="Berufsunteroffizier"
replace offshore=	0	if pro07 =="Betagtenbetreuer"
replace offshore=	0	if pro07 =="Broreiniger"
replace offshore=	0	if pro07 =="Coiffeur"
replace offshore=	0	if pro07 =="Daktyloskop"
replace offshore=	0	if pro07 =="Empfangshostess"
replace offshore=	0	if pro07 =="Englischlehrer"
replace offshore=	0	if pro07 =="Friseur"
replace offshore=	0	if pro07 =="Frster"
replace offshore=	0	if pro07 =="Gemeindepolizist"
replace offshore=	0	if pro07 =="Gymnasiallehrer"
replace offshore=	0	if pro07 =="Grtnereiangestellter"
replace offshore=	0	if pro07 =="Hausbeamter"
replace offshore=	0	if pro07 =="Hauspfleger"
replace offshore=	0	if pro07 =="Hauswart"
replace offshore=	0	if pro07 =="Heimleiter"
replace offshore=	0	if pro07 =="Hundecoiffeur"
replace offshore=	0	if pro07 =="Instandhaltungsleiter"
replace offshore=	0	if pro07 =="Kinderbetreuer"
replace offshore=	0	if pro07 =="Kindergrtner"
replace offshore=	0	if pro07 =="Kinderkrippenbetreuer"
replace offshore=	0	if pro07 =="Kleinkindererzieher"
replace offshore=	0	if pro07 =="Kleinkinderschullehrer"
replace offshore=	0	if pro07 =="Krankenpfleger"
replace offshore=	0	if pro07 =="Krankenpfleger FA SRK"
replace offshore=	0	if pro07 =="Krippenleiter"
replace offshore=	0	if pro07 =="Landarbeiter"
replace offshore=	0	if pro07 =="Landjger"
replace offshore=	0	if pro07 =="Landschaftsgrtner"
replace offshore=	0	if pro07 =="Landwirt"
replace offshore=	0	if pro07 =="Lehrer"
replace offshore=	0	if pro07 =="Lehrer an Primarschule"
replace offshore=	0	if pro07 =="Lehrer an einer Schule der Sekundarstufe I"
replace offshore=	0	if pro07 =="Lokomotivfhrer"
replace offshore=	0	if pro07 =="Mathematiklehrer"
replace offshore=	0	if pro07 =="Maurer"
replace offshore=	0	if pro07 =="Maurerhandlanger"
replace offshore=	0	if pro07 =="Mittelschullehrer"
replace offshore=	0	if pro07 =="Nurse"
replace offshore=	0	if pro07 =="Oberpfleger"
replace offshore=	0	if pro07 =="Oberstufenlehrer"
replace offshore=	0	if pro07 =="Pflegeassistent"
replace offshore=	0	if pro07 =="Polizeibeamter"
replace offshore=	0	if pro07 =="Polizeigehilfe"
replace offshore=	0	if pro07 =="Polizeiinspektor"
replace offshore=	0	if pro07 =="Polizist"
replace offshore=	0	if pro07 =="Postautochauffeur"
replace offshore=	0	if pro07 =="Praxisassistent, medizinischer"
replace offshore=	0	if pro07 =="Praxishilfe"
replace offshore=	0	if pro07 =="Primarlehrer"
replace offshore=	0	if pro07 =="Primarschullehrer"
replace offshore=	0	if pro07 =="Putzmann"
replace offshore=	0	if pro07 =="Raumpfleger"
replace offshore=	0	if pro07 =="Receptionist"
replace offshore=	0	if pro07 =="Reinigungsarbeiter"
replace offshore=	0	if pro07 =="Religionslehrer"
replace offshore=	0	if pro07 =="Richter"
replace offshore=	0	if pro07 =="Schulabwart"
replace offshore=	0	if pro07 =="Schulbusfahrer"
replace offshore=	0	if pro07 =="Schulhausabwart"
replace offshore=	0	if pro07 =="Sekundarlehrer"
replace offshore=	0	if pro07 =="Sekuritaswchter"
replace offshore=	0	if pro07 =="Sicherheitsbeamter"
replace offshore=	0	if pro07 =="Spitex-Hauspfleger"
replace offshore=	0	if pro07 =="Tiefbaumaurer"
replace offshore=	0	if pro07 =="Volksschullehrer"
replace offshore=	0	if pro07 =="Winzer"
replace offshore=	0	if pro07 =="Zugfhrer"
replace offshore=	1	if pro07 =="Restaurationsangestellter, Service"
replace offshore=	1	if pro07 =="Serviceangestellter"
replace offshore=	1	if pro07 =="Servicefachangestellter"
replace offshore=	1	if pro07 =="Servierer"
replace offshore=	1	if pro07 =="Werkstattleiter"
replace offshore=	1	if pro07 =="Zimmerkellner"
replace offshore=	2	if pro07 =="Aromatiker"
replace offshore=	2	if pro07 =="Fahrdienstleiter"
replace offshore=	2	if pro07 =="Leiter Teleinformatik"
replace offshore=	2	if pro07 =="Leiter des technischen Kundendienstes/Service"
replace offshore=	2	if pro07 =="Technischer Betriebsleiter"
replace offshore=	3	if pro07 =="Rangierangestellter"
replace offshore=	3	if pro07 =="Versandangestellter"
replace offshore=	4	if pro07 =="Dentalassistent"
replace offshore=	4	if pro07 =="Dentalhygieniker"
replace offshore=	4	if pro07 =="Gastwirt"
replace offshore=	4	if pro07 =="Hoteldirektor"
replace offshore=	4	if pro07 =="Kinderpfleger"
replace offshore=	4	if pro07 =="Matre d'htel"
replace offshore=	4	if pro07 =="PTT-Zustellbeamter"
replace offshore=	4	if pro07 =="Postbote"
replace offshore=	4	if pro07 =="Restaurantleiter"
replace offshore=	4	if pro07 =="Tierarztgehilfe"
replace offshore=	4	if pro07 =="Wirt"
replace offshore=	5	if pro07 =="Bahnbeamter"
replace offshore=	5	if pro07 =="Bodenleger"
replace offshore=	5	if pro07 =="Kser"
replace offshore=	5	if pro07 =="Ksereiangestellter"
replace offshore=	5	if pro07 =="Plattenleger"
replace offshore=	6	if pro07 =="Kosmetiker"
replace offshore=	6	if pro07 =="Strassenarbeiter"
replace offshore=	6	if pro07 =="Strassenbauer"
replace offshore=	6	if pro07 =="Strassenunterhaltsarbeiter"
replace offshore=	6	if pro07 =="Zustellbeamter, Post"
replace offshore=	7	if pro07 =="Antiquar"
replace offshore=	7	if pro07 =="Detailhandelsangestellter"
replace offshore=	7	if pro07 =="Drogist"
replace offshore=	7	if pro07 =="Kassier"
replace offshore=	7	if pro07 =="Katechet"
replace offshore=	7	if pro07 =="Metzgereiverkufer"
replace offshore=	7	if pro07 =="Pastor"
replace offshore=	7	if pro07 =="Pfarrer"
replace offshore=	7	if pro07 =="Schmuck- und Uhrenverkufer"
replace offshore=	7	if pro07 =="Schuhverkufer"
replace offshore=	7	if pro07 =="Verkufer"
replace offshore=	7	if pro07 =="Verkufer von Bchern in Buchhandlung"
replace offshore=	7	if pro07 =="Warenhausverkufer"
replace offshore=	8	if pro07 =="Altenbetreuer"
replace offshore=	8	if pro07 =="Asylantenbetreuer"
replace offshore=	8	if pro07 =="Babysitter"
replace offshore=	8	if pro07 =="Hauswirtschaftlicher Betriebsleiter"
replace offshore=	8	if pro07 =="Medizinischer Betreuer"
replace offshore=	9	if pro07 =="Asphalteur"
replace offshore=	9	if pro07 =="Erzieher"
replace offshore=	9	if pro07 =="Hauswirtschaftlicher Angestellter"
replace offshore=	9	if pro07 =="Hilfspfleger"
replace offshore=	9	if pro07 =="Pflegedienstleiter"
replace offshore=	9	if pro07 =="Pflegefachmann"
replace offshore=	9	if pro07 =="Pflegefachmann FH"
replace offshore=	9	if pro07 =="Pflegefachmann, dipl., srk"
replace offshore=	9	if pro07 =="Wegmacher"
replace offshore=	10	if pro07 =="Animator (Sozialbereich)"
replace offshore=	10	if pro07 =="Behindertenheimleiter"
replace offshore=	10	if pro07 =="Behindertensportleiter"
replace offshore=	10	if pro07 =="Betagtenanimator"
replace offshore=	10	if pro07 =="Betreuer"
replace offshore=	10	if pro07 =="Diplomierter in sozialer Arbeit FH"
replace offshore=	10	if pro07 =="Entwicklungshelfer"
replace offshore=	10	if pro07 =="Frsorger"
replace offshore=	10	if pro07 =="Heilpdagoge"
replace offshore=	10	if pro07 =="Heilsarmeeoffizier"
replace offshore=	10	if pro07 =="Musiklehrer"
replace offshore=	10	if pro07 =="Musikpdagoge"
replace offshore=	10	if pro07 =="Sonderklassenlehrer"
replace offshore=	10	if pro07 =="Sozialamtsmitarbeiter"
replace offshore=	10	if pro07 =="Sozialberater"
replace offshore=	10	if pro07 =="Sozialbetreuer"
replace offshore=	10	if pro07 =="Sozialfrsorgeverwalter"
replace offshore=	11	if pro07 =="AHV-Zweigstellenleiter"
replace offshore=	11	if pro07 =="Abteilungsvorsteher (ffentlicher Dienst, leitende Funktion)"
replace offshore=	11	if pro07 =="Betriebsleiter (ffentlicher Dienst)"
replace offshore=	11	if pro07 =="Diplomat"
replace offshore=	11	if pro07 =="Leiter Kantonspolizeiposten"
replace offshore=	11	if pro07 =="Poststellenleiter"
replace offshore=	12	if pro07 =="Bibliothekar"
replace offshore=	12	if pro07 =="Bibliotheksangestellter"
replace offshore=	14	if pro07 =="Fahrlehrer"
replace offshore=	17	if pro07 =="Automechaniker"
replace offshore=	17	if pro07 =="Direktor Industrie"
replace offshore=	17	if pro07 =="Direktor Marketing"
replace offshore=	17	if pro07 =="Direktor Maschinenindustrie"
replace offshore=	17	if pro07 =="Direktor Metallindustrie"
replace offshore=	17	if pro07 =="Finanzchef"
replace offshore=	17	if pro07 =="Finanzdirektor (Privatwirtschaft)"
replace offshore=	17	if pro07 =="Juristischer Direktor"
replace offshore=	17	if pro07 =="Kinodirektor"
replace offshore=	17	if pro07 =="Kioskverkufer"
replace offshore=	17	if pro07 =="Nahrungsmittelfabrikant"
replace offshore=	17	if pro07 =="Unternehmer, dipl. SIU"
replace offshore=	17	if pro07 =="Vizedirektor (Privatwirtschaft)"
replace offshore=	17	if pro07 =="Werklehrer"
replace offshore=	19	if pro07 =="Bcker-Konditor"
replace offshore=	19	if pro07 =="Feinbcker"
replace offshore=	19	if pro07 =="Galerist"
replace offshore=	19	if pro07 =="Klimatisationstechniker"
replace offshore=	19	if pro07 =="Konfiserieleiter"
replace offshore=	19	if pro07 =="Metzger"
replace offshore=	20	if pro07 =="Arbeitsschullehrer"
replace offshore=	20	if pro07 =="Ausbildungsspezialist"
replace offshore=	20	if pro07 =="Baudirektor"
replace offshore=	20	if pro07 =="Baumeister"
replace offshore=	20	if pro07 =="Bauprojektleiter"
replace offshore=	20	if pro07 =="Bauunternehmer"
replace offshore=	20	if pro07 =="Berufsausbildner"
replace offshore=	20	if pro07 =="Berufsausbildung"
replace offshore=	20	if pro07 =="Berufsschullehrer"
replace offshore=	20	if pro07 =="Haushaltlehrer"
replace offshore=	20	if pro07 =="Leiter Informatikausbildung"
replace offshore=	20	if pro07 =="Polier"
replace offshore=	21	if pro07 =="Chauffeur"
replace offshore=	21	if pro07 =="Chauffeur, ffentlicher Verkehr"
replace offshore=	21	if pro07 =="Flugverkehrskontrolleur"
replace offshore=	21	if pro07 =="Hafner"
replace offshore=	24	if pro07 =="Advokat und Notar"
replace offshore=	24	if pro07 =="Anwalt"
replace offshore=	24	if pro07 =="Arzt"
replace offshore=	24	if pro07 =="Arzt fuer osteopathische medizin"
replace offshore=	24	if pro07 =="Bewegungstherapeut"
replace offshore=	24	if pro07 =="Dr. med. vet. "
replace offshore=	24	if pro07 =="Ergotherapeut"
replace offshore=	24	if pro07 =="Feldenkraislehrer"
replace offshore=	24	if pro07 =="Frauenarzt"
replace offshore=	24	if pro07 =="Journalist"
replace offshore=	24	if pro07 =="Journalist BR"
replace offshore=	24	if pro07 =="Lagerangestellter"
replace offshore=	24	if pro07 =="Lagerarbeiter"
replace offshore=	24	if pro07 =="Lagerchef"
replace offshore=	24	if pro07 =="Lagerist"
replace offshore=	24	if pro07 =="Magazinarbeiter"
replace offshore=	24	if pro07 =="Masseur"
replace offshore=	24	if pro07 =="Medizinischer Masseur"
replace offshore=	24	if pro07 =="Medizinischer Masseur SRK"
replace offshore=	24	if pro07 =="Physiotherapeut"
replace offshore=	24	if pro07 =="Redaktionsmitarbeiter"
replace offshore=	24	if pro07 =="Redaktor"
replace offshore=	24	if pro07 =="Spezialarzt"
replace offshore=	24	if pro07 =="Verantwortlicher Redaktor"
replace offshore=	24	if pro07 =="Zahnarzt"
replace offshore=	25	if pro07 =="Anlagentechniker"
replace offshore=	25	if pro07 =="Architekt"
replace offshore=	25	if pro07 =="Bauamtsarbeiter"
replace offshore=	25	if pro07 =="Bauer"
replace offshore=	25	if pro07 =="Baufach"
replace offshore=	25	if pro07 =="Baumaschinist"
replace offshore=	25	if pro07 =="Betriebsangestellter PTT"
replace offshore=	25	if pro07 =="Betriebsangestellter, Post"
replace offshore=	25	if pro07 =="Betriebsleiter, Post"
replace offshore=	25	if pro07 =="Choreograph"
replace offshore=	25	if pro07 =="Dipl. Vermessungsingenieur ETH"
replace offshore=	25	if pro07 =="Dozent"
replace offshore=	25	if pro07 =="Flight Attendant"
replace offshore=	25	if pro07 =="Fotograf"
replace offshore=	25	if pro07 =="Gastronomiefachmann"
replace offshore=	25	if pro07 =="Gemeindearbeiter"
replace offshore=	25	if pro07 =="Gemeindeinspektor"
replace offshore=	25	if pro07 =="Gemeindeschreiber"
replace offshore=	25	if pro07 =="Hilfskoch"
replace offshore=	25	if pro07 =="Hotelfachangestellter"
replace offshore=	25	if pro07 =="Hotelfachmann"
replace offshore=	25	if pro07 =="Hotelfhrer"
replace offshore=	25	if pro07 =="Hotellerieangestellter EBA"
replace offshore=	25	if pro07 =="Inventarbeamter"
replace offshore=	25	if pro07 =="Kaufmnnischer Angestellter, ffentliche Verwaltung"
replace offshore=	25	if pro07 =="Kranfhrer"
replace offshore=	25	if pro07 =="Lebensmittelinspektor"
replace offshore=	25	if pro07 =="Lehrbeauftragter an Hochschule"
replace offshore=	25	if pro07 =="Logistikassistent Distribution (Post)"
replace offshore=	25	if pro07 =="Maskenbildner"
replace offshore=	25	if pro07 =="Medizinischer Fotograf"
replace offshore=	25	if pro07 =="Postassistent"
replace offshore=	25	if pro07 =="Postbeamter"
replace offshore=	25	if pro07 =="Postbroangestellter"
replace offshore=	25	if pro07 =="Posthalter"
replace offshore=	25	if pro07 =="Postverwalter"
replace offshore=	25	if pro07 =="Pdagoge"
replace offshore=	25	if pro07 =="Schulanimator"
replace offshore=	25	if pro07 =="Sortiments- und Verlagsbuchhndler, Verlagsbuchhndler"
replace offshore=	25	if pro07 =="Sozialpdagoge"
replace offshore=	25	if pro07 =="Steuerbeamter"
replace offshore=	25	if pro07 =="Steward"
replace offshore=	25	if pro07 =="Universittsprofessor"
replace offshore=	25	if pro07 =="Verlagsassistent"
replace offshore=	25	if pro07 =="Verwaltungsangestellter"
replace offshore=	25	if pro07 =="Weibel"
replace offshore=	25	if pro07 =="Werkzeugmacher"
replace offshore=	25	if pro07 =="Zivilstandsbeamter"
replace offshore=	25	if pro07 =="Zollangestellter"
replace offshore=	26	if pro07 =="Betriebsmechaniker"
replace offshore=	26	if pro07 =="Filialleiter Lebensmittelbranche"
replace offshore=	26	if pro07 =="Filialleiter Textilbranche"
replace offshore=	26	if pro07 =="Geburtshelfer"
replace offshore=	26	if pro07 =="Gestionnaire du commerce de detail"
replace offshore=	26	if pro07 =="Grosshndler"
replace offshore=	26	if pro07 =="Koch"
replace offshore=	26	if pro07 =="Kochgehilfe"
replace offshore=	26	if pro07 =="Kchenangestellter"
replace offshore=	26	if pro07 =="Kchenchef"
replace offshore=	26	if pro07 =="Kchenhelfer"
replace offshore=	26	if pro07 =="Kchenmeister"
replace offshore=	26	if pro07 =="Ladenverantwortlicher"
replace offshore=	26	if pro07 =="Leiter Verkaufsfiliale"
replace offshore=	26	if pro07 =="Mechaniker"
replace offshore=	26	if pro07 =="Mechaniker-Techniker"
replace offshore=	26	if pro07 =="Netzelektrikermeister HFP"
replace offshore=	26	if pro07 =="Netzmonteur"
replace offshore=	26	if pro07 =="Polymechaniker"
replace offshore=	26	if pro07 =="Schuhgeschftsleiter"
replace offshore=	27	if pro07 =="Betriebselektriker"
replace offshore=	27	if pro07 =="Damenschneider"
replace offshore=	27	if pro07 =="Konfektionsschneider"
replace offshore=	27	if pro07 =="Schneider"
replace offshore=	27	if pro07 =="Schneidermeister"
replace offshore=	28	if pro07 =="Agraringenieur"
replace offshore=	28	if pro07 =="Transportchauffeur"
replace offshore=	29	if pro07 =="Schreiner"
replace offshore=	30	if pro07 =="Metallarbeiter"
replace offshore=	30	if pro07 =="Schlosser"
replace offshore=	32	if pro07 =="Packereichef"
replace offshore=	33	if pro07 =="Automatiker"
replace offshore=	33	if pro07 =="Elektriker"
replace offshore=	33	if pro07 =="Elektromechaniker"
replace offshore=	33	if pro07 =="Feinmechaniker"
replace offshore=	34	if pro07 =="Fachlehrer"
replace offshore=	34	if pro07 =="Fachlehrer Fotografie"
replace offshore=	34	if pro07 =="Fremdsprachenlehrer"
replace offshore=	34	if pro07 =="Kursleiter, Handarbeit"
replace offshore=	34	if pro07 =="Spanischlehrer"
replace offshore=	34	if pro07 =="Sprachlehrer"
replace offshore=	36	if pro07 =="Optiker"
replace offshore=	37.5	if pro07 =="Jurist"
replace offshore=	37.5	if pro07 =="Juristischer Mitarbeiter"
replace offshore=	37.5	if pro07 =="Juristischer Sekretr"
replace offshore=	37.5	if pro07 =="Kaufmann, Profil b, Notariat"
replace offshore=	37.5	if pro07 =="Notariatskanzlist"
replace offshore=	37.5	if pro07 =="Rechtsanwalt"
replace offshore=	39	if pro07 =="Architekturbauzeichner"
replace offshore=	39	if pro07 =="Broangestellter"
replace offshore=	39	if pro07 =="Chefsekretr"
replace offshore=	39	if pro07 =="Direktionsassistent"
replace offshore=	39	if pro07 =="Direktionssekretr"
replace offshore=	39	if pro07 =="Disponent"
replace offshore=	39	if pro07 =="Einkaufsangestellter"
replace offshore=	39	if pro07 =="Einkaufsleiter"
replace offshore=	39	if pro07 =="Einkufer"
replace offshore=	39	if pro07 =="Finanzplaner, eidg. FA"
replace offshore=	39	if pro07 =="Fremdsprachensekretr"
replace offshore=	39	if pro07 =="Geschftsstellenleiter Krankenkasse"
replace offshore=	39	if pro07 =="Industriesekretr"
replace offshore=	39	if pro07 =="Inkassoangestellter"
replace offshore=	39	if pro07 =="Kaufmann"
replace offshore=	39	if pro07 =="Kaufmnnischer Angestellter"
replace offshore=	39	if pro07 =="Kaufmnnischer Angestellter, Maschinenindustrie"
replace offshore=	39	if pro07 =="Kaufmnnischer Angestellter, Telekommunikation"
replace offshore=	39	if pro07 =="Kaufmnnischer Angestellter, Treuhand"
replace offshore=	39	if pro07 =="Kaufmnnischer Assistent"
replace offshore=	39	if pro07 =="Kaufmnnischer Berater"
replace offshore=	39	if pro07 =="Kaufmnnischer Leiter"
replace offshore=	39	if pro07 =="Kaufmnnischer Sachbearbeiter"
replace offshore=	39	if pro07 =="Kurvereinsangestellter"
replace offshore=	39	if pro07 =="Lederarbeiter"
replace offshore=	39	if pro07 =="Sekretariatsangestellter"
replace offshore=	39	if pro07 =="Sekretariatsassistent"
replace offshore=	39	if pro07 =="Sekretr"
replace offshore=	39	if pro07 =="Sekretr-Buchhalter"
replace offshore=	39	if pro07 =="Verkaufsangestellter"
replace offshore=	39	if pro07 =="Verkaufsassistent"
replace offshore=	39	if pro07 =="Verkaufskorrespondent"
replace offshore=	39	if pro07 =="Verkaufsleiter"
replace offshore=	39	if pro07 =="Werksekretr"
replace offshore=	41	if pro07 =="Produktionsmitarbeiter"
replace offshore=	41	if pro07 =="Schichtfhrer"
replace offshore=	42	if pro07 =="Sanitrmonteur"
replace offshore=	42	if pro07 =="Sanitrtechniker"
replace offshore=	44.5	if pro07 =="Apotheker"
replace offshore=	44.5	if pro07 =="Pharma-Assistent"
replace offshore=	45	if pro07 =="Anwaltssekretr"
replace offshore=	45	if pro07 =="Kundendienstberater"
replace offshore=	45	if pro07 =="Kurskoordinator"
replace offshore=	45	if pro07 =="Projektkoordinator"
replace offshore=	45	if pro07 =="Projektmanager"
replace offshore=	45	if pro07 =="Prozessberater"
replace offshore=	45	if pro07 =="Quality Manager"
replace offshore=	45	if pro07 =="Qualittsleiter"
replace offshore=	45	if pro07 =="Techniker TS, Mikroelektronik"
replace offshore=	45	if pro07 =="Verkehrsexperte"
replace offshore=	46	if pro07 =="Gespraechstherapeut"
replace offshore=	46	if pro07 =="Naturheilkundiger"
replace offshore=	46	if pro07 =="Sozialtherapeut"
replace offshore=	47	if pro07 =="Versicherungsabteilungsleiter"
replace offshore=	47	if pro07 =="Versicherungsagent"
replace offshore=	47	if pro07 =="Versicherungsberater"
replace offshore=	47	if pro07 =="Versicherungskaufmann"
replace offshore=	47	if pro07 =="Versicherungssachbearbeiter"
replace offshore=	48	if pro07 =="Generalsekretr"
replace offshore=	48	if pro07 =="Medizinischer sekretaer"
replace offshore=	49	if pro07 =="Filmeinkufer"
replace offshore=	49	if pro07 =="Maschinenmechaniker"
replace offshore=	49	if pro07 =="Reisefhrer"
replace offshore=	50	if pro07 =="Abteilungsleiter Bank"
replace offshore=	50	if pro07 =="Arbeitswissenschafter"
replace offshore=	50	if pro07 =="Bank-Generaldirektor (Privatwirtschaft)"
replace offshore=	50	if pro07 =="Bankangestellter"
replace offshore=	50	if pro07 =="Bankbeamter, dipl."
replace offshore=	50	if pro07 =="Bankberater"
replace offshore=	50	if pro07 =="Bankdirektor"
replace offshore=	50	if pro07 =="Bankier"
replace offshore=	50	if pro07 =="Bankkundenberater"
replace offshore=	50	if pro07 =="Bankprokurist"
replace offshore=	50	if pro07 =="Bankrevisor"
replace offshore=	50	if pro07 =="Banksekretr"
replace offshore=	50	if pro07 =="Erwachsenenbildner"
replace offshore=	50	if pro07 =="Financier"
replace offshore=	50	if pro07 =="Kapitalverwalter"
replace offshore=	50	if pro07 =="Kaufmnnischer Angestellter, Bank"
replace offshore=	50	if pro07 =="Kaufmnnischer Bankangestellter"
replace offshore=	50	if pro07 =="Konsulent in Handelssachen"
replace offshore=	50	if pro07 =="Manager Import-Export-Gesellschaft"
replace offshore=	50	if pro07 =="Reiseberater"
replace offshore=	50	if pro07 =="Sparkassenfachwirt"
replace offshore=	50	if pro07 =="Uhrmacher"
replace offshore=	50	if pro07 =="Vermgensverwalter"
replace offshore=	50	if pro07 =="Wissenschaftlicher Assistent"
replace offshore=	50	if pro07 =="Zahntechniker"
replace offshore=	51	if pro07 =="Auto- und Wagenlackierer"
replace offshore=	51	if pro07 =="Autolackierer"
replace offshore=	51	if pro07 =="Brandschutzmonteur"
replace offshore=	51	if pro07 =="Dekorateur"
replace offshore=	51	if pro07 =="Dekorationsgestalter"
replace offshore=	51	if pro07 =="Flugzeugbauer"
replace offshore=	51	if pro07 =="Flugzeugmechaniker"
replace offshore=	51	if pro07 =="Head hunter"
replace offshore=	51	if pro07 =="Leiter Human Resources"
replace offshore=	51	if pro07 =="Leiter Personaladministration"
replace offshore=	51	if pro07 =="Leiter Personaldienst"
replace offshore=	51	if pro07 =="Montagearbeiter"
replace offshore=	51	if pro07 =="Montageleiter"
replace offshore=	51	if pro07 =="Monteur"
replace offshore=	51	if pro07 =="Personalberater, eidg. FA"
replace offshore=	51	if pro07 =="Personalsekretr"
replace offshore=	51	if pro07 =="Personaltrainer"
replace offshore=	51	if pro07 =="Personalverantwortlicher"
replace offshore=	51	if pro07 =="Remonteur"
replace offshore=	51	if pro07 =="Servicemonteur"
replace offshore=	52	if pro07 =="Maschinenheizer"
replace offshore=	53	if pro07 =="Apparate-Entwickler"
replace offshore=	53	if pro07 =="Elektroanlagenbauleiter"
replace offshore=	53	if pro07 =="Elektroberater"
replace offshore=	53	if pro07 =="Elektromonteur"
replace offshore=	53	if pro07 =="Goldschmied"
replace offshore=	53	if pro07 =="Marketingassistent"
replace offshore=	53	if pro07 =="Marketingleiter"
replace offshore=	53	if pro07 =="Marketingleiter, dipl. HFP"
replace offshore=	53	if pro07 =="Marketingplaner"
replace offshore=	53	if pro07 =="Marktforscher"
replace offshore=	53.5	if pro07 =="Soziologe"
replace offshore=	54	if pro07 =="Rntgentechniker"
replace offshore=	54	if pro07 =="Servicetechniker"
replace offshore=	54	if pro07 =="Techniker HF, Leitung Industrieller Projekte"
replace offshore=	54	if pro07 =="Techniker TS"
replace offshore=	54	if pro07 =="Theaterbeleuchter"
replace offshore=	55	if pro07 =="Feuerungsfachmann, Oel"
replace offshore=	55	if pro07 =="Fundraiser"
replace offshore=	55	if pro07 =="Technischer Verkaufsberater"
replace offshore=	55	if pro07 =="Unternehmensberater"
replace offshore=	55	if pro07 =="Verkaufsberater"
replace offshore=	55	if pro07 =="Wirtschaftsberater"
replace offshore=	56	if pro07 =="Waschmann"
replace offshore=	56	if pro07 =="Wschereiangestellter"
replace offshore=	56	if pro07 =="Wschereileiter"
replace offshore=	58	if pro07 =="Baumaler"
replace offshore=	58	if pro07 =="Gipser und Maler"
replace offshore=	58	if pro07 =="Maler"
replace offshore=	58	if pro07 =="Malermeister"
replace offshore=	58.5	if pro07 =="Berufsberater"
replace offshore=	58.5	if pro07 =="Jugendpsychologe"
replace offshore=	58.5	if pro07 =="Psychiater"
replace offshore=	58.5	if pro07 =="Psychologe"
replace offshore=	58.5	if pro07 =="Psychotherapeut"
replace offshore=	58.5	if pro07 =="Schulpsychologe"
replace offshore=	59	if pro07 =="Biologielaborant"
replace offshore=	59	if pro07 =="Chemiearbeiter"
replace offshore=	59	if pro07 =="Chemielaborant"
replace offshore=	59	if pro07 =="Chemielaborleiter"
replace offshore=	59	if pro07 =="Stahlwalzer"
replace offshore=	60	if pro07 =="Tpfer"
replace offshore=	61	if pro07 =="AVOR-Projektleiter"
replace offshore=	61	if pro07 =="Medizinisch-technischer Assistent"
replace offshore=	62	if pro07 =="Buchhaltungsrevisor"
replace offshore=	62	if pro07 =="Bcherexperte"
replace offshore=	62	if pro07 =="Elektroniker"
replace offshore=	62.5	if pro07 =="Angestellter Geschftsleitung"
replace offshore=	62.5	if pro07 =="Bereichsleiter Finanzen"
replace offshore=	62.5	if pro07 =="Betriebsverantwortlicher (Privatwirtschaft, leitende Funktion)"
replace offshore=	62.5	if pro07 =="Betriebskonom FH, Facility Management"
replace offshore=	62.5	if pro07 =="Finanz-Analytiker"
replace offshore=	62.5	if pro07 =="Finanzagent"
replace offshore=	62.5	if pro07 =="Finanzexperte"
replace offshore=	62.5	if pro07 =="Finanzmitarbeiter"
replace offshore=	62.5	if pro07 =="Finanzspezialist"
replace offshore=	62.5	if pro07 =="Managementassistent"
replace offshore=	62.5	if pro07 =="Wirtschaftswissenschafter"
replace offshore=	62.5	if pro07 =="konom"
replace offshore=	64	if pro07 =="Logistiker"
replace offshore=	64	if pro07 =="Logistikleiter"
replace offshore=	64	if pro07 =="Logistikmanager"
replace offshore=	64	if pro07 =="Speditionsangestellter"
replace offshore=	64	if pro07 =="Speditionspacker"
replace offshore=	64	if pro07 =="Sger in Uhrsteinfabrik"
replace offshore=	64	if pro07 =="Uhrenarbeiter"
replace offshore=	65	if pro07 =="Vermittler"
replace offshore=	68	if pro07 =="Decolleteur"
replace offshore=	71	if pro07 =="Mbelschreiner"
replace offshore=	71	if pro07 =="Weissnher"
replace offshore=	72	if pro07 =="Archivar"
replace offshore=	72	if pro07 =="Dokumentalist"
replace offshore=	73	if pro07 =="Gerant"
replace offshore=	73	if pro07 =="Husermakler"
replace offshore=	73	if pro07 =="Immobilienberater"
replace offshore=	73	if pro07 =="Immobilienverwalter"
replace offshore=	74	if pro07 =="Diamantwerkzeugmacher"
replace offshore=	74	if pro07 =="Dipl. Maschineningenieur ETH"
replace offshore=	74	if pro07 =="Elektroingenieur"
replace offshore=	74	if pro07 =="Elektronikingenieur"
replace offshore=	74	if pro07 =="Maschinenbauingenieur HTL"
replace offshore=	74	if pro07 =="Maschinenbauleiter"
replace offshore=	74	if pro07 =="Maschineningenieur"
replace offshore=	74	if pro07 =="Maschinenkonstruktionsingenieur"
replace offshore=	75	if pro07 =="Event Manager"
replace offshore=	75	if pro07 =="Textilchemiker"
replace offshore=	75	if pro07 =="Textilmechaniker"
replace offshore=	75	if pro07 =="Trikotstricker"
replace offshore=	75	if pro07 =="Veranstaltungsorganisator"
replace offshore=	76	if pro07 =="Dipl. Ingenieur"
replace offshore=	76	if pro07 =="Dipl. Ingenieur ETH"
replace offshore=	76	if pro07 =="Meteorologischer Mitarbeiter"
replace offshore=	76	if pro07 =="Projektingenieur"
replace offshore=	76	if pro07 =="Systemingenieur"
replace offshore=	76	if pro07 =="Verkaufsingenieur"
replace offshore=	76	if pro07 =="Zivilingenieur"
replace offshore=	77	if pro07 =="Hochbauzeichner"
replace offshore=	77	if pro07 =="Steuerexperte"
replace offshore=	77	if pro07 =="Treuhnder"
replace offshore=	77	if pro07 =="Trust Officer"
replace offshore=	77	if pro07 =="Wirtschaftsprfer"
replace offshore=	81	if pro07 =="Chemieanalytiker"
replace offshore=	81	if pro07 =="Chemiker"
replace offshore=	81	if pro07 =="Typograf"
replace offshore=	83	if pro07 =="Biologe"
replace offshore=	83	if pro07 =="Laborant"
replace offshore=	83	if pro07 =="Modezeichner"
replace offshore=	84	if pro07 =="Buchhalter"
replace offshore=	84	if pro07 =="Buchhalter-Administrator"
replace offshore=	84	if pro07 =="Buchhaltungssekretr"
replace offshore=	84	if pro07 =="Finanzbuchhalter"
replace offshore=	84	if pro07 =="Handelsmann"
replace offshore=	84	if pro07 =="Hilfsbuchhalter"
replace offshore=	84	if pro07 =="Kreditorenbuchhalter"
replace offshore=	84	if pro07 =="Lebensmittelvertreter"
replace offshore=	84	if pro07 =="Lohnbuchhalter"
replace offshore=	84	if pro07 =="Vertreter"
replace offshore=	87	if pro07 =="Bildermaler"
replace offshore=	87	if pro07 =="Kunstmaler"
replace offshore=	89	if pro07 =="Kommunikationsleiter"
replace offshore=	90	if pro07 =="Medienberater"
replace offshore=	90	if pro07 =="PR-Sachbearbeiter"
replace offshore=	90	if pro07 =="Propagandist"
replace offshore=	90	if pro07 =="Werbeleiter"
replace offshore=	93	if pro07 =="Metteur"
replace offshore=	93	if pro07 =="Technischer Zeichner"
replace offshore=	95	if pro07 =="Offsetdrucker"
replace offshore=	96	if pro07 =="Grafiker"
replace offshore=	96	if pro07 =="Physiker"
replace offshore=	98	if pro07 =="Applikationssupporter"
replace offshore=	98	if pro07 =="EDV-Ingenieur"
replace offshore=	98	if pro07 =="Fotolaborant"
replace offshore=	98	if pro07 =="Ingenieur FH, Informatik"
replace offshore=	98	if pro07 =="Softwareberater"
replace offshore=	98	if pro07 =="Systemmanager"
replace offshore=	45	if pro07 =="Technischer Supporter"
replace offshore=	98	if pro07 =="Wirtschaftsinformatiker"
replace offshore=	100	if pro07 =="Datamanager"
replace offshore=	100	if pro07 =="EDV-Projektassistent"
replace offshore=	45	if pro07 =="IT-Supporter"
replace offshore=	100	if pro07 =="Informatikentwicklungsleiter"
replace offshore=	100	if pro07 =="Informatiker"
replace offshore=	100	if pro07 =="Informatiker EFZ"
replace offshore=	100	if pro07 =="Informatiker HTL"
replace offshore=	100	if pro07 =="Informatikprojektchef"
replace offshore=	100	if pro07 =="Informatiktechniker"
replace offshore=	100	if pro07 =="Operator"
replace offshore=	100	if pro07 =="Softwareentwickler"
replace offshore=	100	if pro07 =="Systemanalytiker"
replace offshore=	100	if pro07 =="Telefonist"
replace offshore=	100	if pro07 =="Teleoperateur"
replace offshore=	100	if pro07 =="Webmaster"
replace offshore=	100	if pro07 =="bersetzer"
replace offshore=	.	if pro07 =="Anderes"
replace offshore=	.	if pro07 =="Keine Angabe"
replace offshore=	.	if pro07 =="zz (missing) "
replace offshore=	.	if pro07 =="rztebesucher"


* Generate categories for  offshore variable
* ------------------------------------------
gen offshore4=.
label var offshore4 "offshore categories (0 no offsh. 3 high offsh.)"
replace offshore4=0 if offshore<26
replace offshore4=1 if offshore>25 & offshore<51
replace offshore4=2 if offshore>50 & offshore<76
replace offshore4=3 if offshore>75 & offshore<101


* Offshore-Dummies
* ------------------------------------------
gen low_offshore=offshore4==2
gen medium_offshore=offshore4==3
gen high_offshore=offshore4==4


* ===========================================================================================
* 1.1.4 Skills (education)
* ===========================================================================================
* Skills are operationalized as highest educational degree received
* Recoding is based on standard recode for Switzerland (VOX)
* This section of the code (skills) was developed by Sarah Btikofer

generate skills=.
replace skills=0 if v238_07==0 
replace skills=1 if inlist(v238_07,1,2) 
replace skills=2 if inlist(v238_07,3,4) 
replace skills=3 if inlist(v238_07,5,6,7,8) 
replace skills=4 if inlist(v238_07,9,10) 
replace skills=5 if inlist(v238_07,11) 
replace skills=6 if inlist(v238_07,12) 

label de skills 0"no school" 1"primary school" 2"high school/apprenticeship" 3"Matur/higher professional school" ///
	 4"higher professional education (Meister)" 5"polytechnique university" 6"University degree"
label val skills skills
label var skills "Skill-Level (Education)"


* ===========================================================================================
* 1.1.5 INTERACTION TERMS
* ===========================================================================================

* Set different skill levels at 0
* ________________________________________________________________________________
gen skill1=skills-1
gen skill2=skills-2
gen skill3=skills-3
gen skill4=skills-4
gen skill5=skills-5
gen skill6=skills-6

* Interaction with trade*skills
* ________________________________________________________________________________
gen trade_skills=skills*tradeexposure
label var trade_skills "Tradeexp.x Skills"
gen trade_skills1=tradeexposure*skill1
gen trade_skills2=tradeexposure*skill2
gen trade_skills3=tradeexposure*skill3
gen trade_skills4=tradeexposure*skill4
gen trade_skills5=tradeexposure*skill5
gen trade_skills6=tradeexposure*skill6

* Interaction with fdi*skills
* ________________________________________________________________________________
gen skill_fdi=skills*logfdi
label var trade_skills "Skills x FDI (log)"
gen sfdi1=logfdi*skill1
gen sfdi2=logfdi*skill2
gen sfdi3=logfdi*skill3
gen sfdi4=logfdi*skill4
gen sfdi5=logfdi*skill5
gen sfdi6=logfdi*skill6

* Interaction with offshore*skills
* ________________________________________________________________________________
* Interaktion Skills* Offshore
gen skill_offshore=skills*offshore
label var skill_offshore "Skills x Offshoreability"
gen so1=skill1*offshore
gen so2=skill2*offshore
gen so3=skill3*offshore
gen so4=skill4*offshore
gen so5=skill5*offshore
gen so6=skill6*offshore


* ********************************************************************************************
* 1.2 Dependent Variables
* ********************************************************************************************

* ===========================================================================================
* 1.2.1 ECONOMIC INSECURITY
* ===========================================================================================
* This is a dummy variable based on v48 and v49 in the WVS Survey.
* The dummy takes the value of one if the respondent mentioned "a safe job, where one does not 
* have to be worried about losing the job" as the most (v48) or second most (v49) important
* characteristic he or she would look for in a job if he or she were to search for new employment,
* and zero otherwise.

gen safejob1=.
replace safejob1=1 if v48==2
replace safejob1=0 if v48~=2 & v48<.

gen safejob2=.
replace safejob2=1 if v49==2
replace safejob2=0 if v49~=2 & v49<.

gen safejob=safejob1
replace safejob=1 if safejob2==1
label var safejob "Safe job important (Economic Insecurity)"

* ===========================================================================================
* 1.2.2 DEMANDS FOR COMPENSATION (SOCIAL POLICY PREFERENCE)
* ===========================================================================================
* This is a 10-point ordinal variable (v118). 
* Respondents were asked the state on the 11-point-scale whether they believed that the state 
* or the individual should take more responsibility.
* The variable is recoded so that higher values indicate that the respondent believes that the
* state should take more responsibility.

gen morestate=v118
recode morestate (1=10) (2=9) (3=8) (4=7) (5=6) (6=5) (7=4) (8=3) (9=2) (10=1) if v260==2007
label var morestate "Welfare State Preference, 10= State should take more responsibility  (v118)"
* label define more_state 1"Individual should take more responsibility" 10"State should take more responsibility"
* label val more_state more_state



* ===========================================================================================
* 1.2.3	PARTISAN PREFERENCE FOR THE LEFT (SOCIAL DEMOCRATIC PARTY)
* ===========================================================================================
* This is a dummy variable based on v231, which takes the value of 1 if the respondent states 
* that he or she is planning to vote for the Social Democratic Party (SP) in the net election, 
* and zero otherwise

gen sp=v231==3
replace sp=. if v231==.
label var sp "SP-Vote intention"



* ********************************************************************************************
* 1.3 Control Variables
* ********************************************************************************************

* ===========================================================================================
* 1.3.1 INCOME
* ===========================================================================================
* Income is measured on an ordinal 13-point scale (v253).


* Income
* -------------------------------------------------------------
gen income=.
replace income=1 if v253_07==1 
replace income=2 if v253_07==2 
replace income=3 if v253_07==3
replace income=4 if v253_07==4 
replace income=5 if v253_07==5 
replace income=6 if v253_07==6 
replace income=7 if v253_07==7 
replace income=8 if v253_07==8
replace income=9 if v253_07==9 
replace income=10 if v253_07==10 
replace income=11 if v253_07==11 
replace income=12 if v253_07==12 
replace income=13 if v253_07==13 
label var income "Income (13-point scale)"

* ===========================================================================================
* 1.3.2 GENDER
* ===========================================================================================
* Dummy variable, 1 for women, 0 for men

gen sex=.
replace sex=0 if v235==1
replace sex=1 if v235==2
label var sex "Female"

* ===========================================================================================
* 1.3.3 AGE
* ===========================================================================================
* Age in years. The WVS Survey asks the year of birth (the last two digits, assuming that the 
* person was born in 19xx). The variable is recoded accordingly.

generate year=.
replace year=v236+1900

generate age=.
replace age=2007-year 
label var age "Age in years"

* ===========================================================================================
* 1.3.4 LABOR UNION MEMBERSHIP
* ===========================================================================================
* Dummy variable if respondent is a (active and inactive) member in a labor union.

gen union=.
replace union=1 if v27<3
replace union=0 if v27==3
label var union "Union-Member"

* ===========================================================================================
* 1.3.5 SECTORAL UNEMPLOYMENT RATE
* ===========================================================================================
* This variable records the unemployment rate by sector of employment
* Source: ILO Laborstats (http://laborsta.ilo.org/)

gen ALquote_B=.
label var ALquote_B "Sectoral unemployment rate in %"
replace ALquote_B=0.65 if sec07==1
replace ALquote_B=4.11 if sec07>1 & sec07<8
replace ALquote_B=2.46 if sec07==8
replace ALquote_B=4.11 if sec07==9
replace ALquote_B=10.61 if sec07==10
replace ALquote_B=3.57 if sec07==11
replace ALquote_B=3.57 if sec07==12
replace ALquote_B=1.7 if sec07==13
replace ALquote_B=3.52 if sec07==14
replace ALquote_B=2.18 if sec07==17 | public==1
replace ALquote_B=1.52 if sec07==15
replace ALquote_B=2.61 if sec07==16
replace ALquote_B=3.29 if sec07>=18 &sec07<=20

* for all respondents whom information on the sector of employment is missing, the overall
* unemployment rate (4%) is used
replace ALquote_B=4.00 if sec07>20 & v260==2007  

* ===========================================================================================
* 1.3.6 RISK AVERSION
* ===========================================================================================
* This variable is based on a question which asks respondents to state how similar they are to a
* person that avoids everything dangerous and prefers a safe environment (v82).
* The variable is recoded such that higher values indicate higher levels of risk aversion.

gen riskaversion=v82
recode riskaversion (1=6) (2=5) (3=4) (4=3) (5=2) (6=1)
label var riskaversion "Risk Aversion"
label def riskaversion 1"not risk averse" 6"very risk averse"
label val riskaversion riskaversion


* ===========================================================================================
* 1.3.5 OPINION ON SWISS EU-MEMBERSHIP
* ===========================================================================================
* Dummy variable that takes the value of 1 if respondent indicates that he/she would surely or 
* rather vote for Switzerland to become a EU-member.

gen eu_dummy=eu<3
replace eu_dummy=. if eu==.
label var eu_dummy "Preference for EU-Membership"


* ********************************************************************************************
* 1.4 Drop Pensioners and Foreigners
* ********************************************************************************************

keep if swiss==1 & age<66





* ********************************************************************************************
* ******************************		2. DESCRIPTIVES		**********************************
* ********************************************************************************************


* ********************************************************************************************
* 2.1 Descriptive Statistics
* ********************************************************************************************

sum safejob morestate sp skills tradeexposure logfdi offshore income sex age union ALquote public riskaversion eu


* ********************************************************************************************
* 2.2 Comparison of sample vs. aggregate employment percentages (Tables A1-A3, Appendix)
* ********************************************************************************************

* ===========================================================================================
* 2.2.1 TRADE (Table A1)
* ===========================================================================================

gen sector=.
label var sector "Sector of Employment"
replace sector=1 if sec07==1
replace sector=2 if sec07>1 & sec07<8
replace sector=3 if sec07==8
replace sector=4 if sec07==9
replace sector=5 if sec07==10
replace sector=6 if sec07==11 | sec07==12 | sec07==14
replace sector=7 if sec07==13
replace sector=8 if sec07==18
replace sector=9 if sec07==17 | sec07==15 | sec07==16 | public==1
replace sector=12 if sec07==19 | sec07==20

label define sector 1 "Agriculture,hunting, forestry"
label define sector 2 "Employment in Industry", add
label define sector 3 "Construction", add
label define sector 4 "Whole and retail trade", add
label define sector 5 "Hotels and restaurants", add
label define sector 6 "Transport, storage and communication", add
label define sector 7 "Finance and intermediation", add
label define sector 8 "Real estate, renting and business activities", add
label define sector 9 "Public sector (including education, health+ social work)", add
label define sector 10 "Education", add
label define sector 11 "Health and social work", add
label define sector 12 "Other community activities, private households", add
label define sector 14 "Public sector, no additional information available", add
label val sector sector

* TABLE A1: COMPARISON OF SAMPLE PERCENTAGES WITH AGGREGATE EMPLOYMENT PERCENTAGES, TRADE
* -------------------------------------------------------------------------------------------
* Aggregated sector
tab sector
* Fine-grained industries 
tab sec07



* ===========================================================================================
* 2.2.2 FDI (Table A2)
* ===========================================================================================

gen sectorf =.
label var sectorf "Sector of Employment, FDI categorization"
replace sectorf =1 if sec07>=1 & sec07<=8
replace sectorf=2 if sec07==9
replace sectorf=3 if sec07==13
replace sectorf =4 if sec07==11 | sec07==12 | sec07==14
replace sectorf =5 if sec07==10 | sec07==15 | sec07==16 | sec07==17 | sec07==18 | sec07==19 | sec07==20 | public==1

label define sectorf 1 "Metal, Machinery, Electronics, Construction, Agriculture", add
label define sectorf 2 "Whole and retail trade", add
label define sectorf 3 "Finance, intermediation, insurance", add
label define sectorf 4 "Transport, communication, IT", add
label define sectorf 5 "Other Services", add
label val sectorf sectorf

* TABLE A2: COMPARISON OF SAMPLE PERCENTAGES WITH AGGREGATE EMPLOYMENT PERCENTAGES, FDI
* -------------------------------------------------------------------------------------------
tab sectorf


* ===========================================================================================
* 2.2.3 OFFSHOREABILITY (Table A3)
* ===========================================================================================
label define offshore4 0 "not offshoreable", add
label define offshore4 1 "somewhat offshoreable", add
label define offshore4 2 "offshoreable", add
label define offshore4 3 "highly offshoreable", add
label val offshore4 offshore4

* TABLE A3: COMPARISON OF SAMPLE PERCENTAGES WITH AGGREGATE EMPLOYMENT PERCENTAGES, OFFSHOREABILITY
* -------------------------------------------------------------------------------------------
tab offshore4



* ********************************************************************************************
* ******************		3. REPLICATION OF REGRESSION ANALYSES		**********************
* ********************************************************************************************

* ********************************************************************************************
* 3.1 LINK 1: GLOBALIZATION AND ECONOMIC INSECURITY (TABLE 1 and 2)
* ********************************************************************************************

* ===========================================================================================
* 3.1.1 TRADE
* ===========================================================================================
logit safejob skills tradeexposure trade_skills income sex age union ALquote public riskaversion [pweight=w_regio]  
fitstat
estimates store trade1

* Predicted Probabilities (Table 2, Link 1)
* ----------------------------------------
logit safejob skills tradeexposure trade_skills income sex age union ALquote public riskaversion [pweight=w_regio]  if age<66
* Globalization Loser (Low Skill, high exposure)
prvalue, x(tradeexposure=0.3093797 skills=1 trade_skills=0.3093797 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Low-Skill Sheltered (Low Skill, low exposure)
prvalue, x(tradeexposure=0 skills=1 trade_skills=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* High-Skill Sheltered (High Skill, low exposure)
prvalue, x(tradeexposure=0 skills=6 trade_skills=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(tradeexposure=0.3093797 skills=6 trade_skills=1.8562782 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 


* ===========================================================================================
* 3.1.2 FDI
* ===========================================================================================
logit safejob skills logfdi  skill_fdi income sex age union ALquote public riskaversion [pweight=w_regio]  if age<66
fitstat
estimates store fdi1

* Predicted Probabilities (Table 2, Link 1)
* ----------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(logfdi=6.778512 skills=1 skill_fdi=6.778512 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Intermediate I (Low Skill, low exposure)
prvalue, x(logfdi=0 skills=1 skill_fdi=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Intermediate I (High Skill, low exposure)
prvalue, x(logfdi=0 skills=6 skill_fdi=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(logfdi=6.778512 skills=6 skill_fdi=40.671072 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 


* ===========================================================================================
* 3.1.3 OFFSHOREABILITY
* ===========================================================================================
logit safejob  skills offshore skill_offshore income sex age union ALquote public riskaversion [pweight=w_regio]  if age<66
fitstat
estimates store offshore1

* Predicted Probabilities (Table 2, Link 1)
* ----------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(offshore=100 skills=1 skill_offshore=100 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Intermediate I (Low Skill, low exposure)
prvalue, x(offshore=0 skills=1 skill_offshore=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Intermediate I (High Skill, low exposure)
prvalue, x(offshore=0 skills=6 skill_offshore=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(offshore=100 skills=6 skill_offshore=600 income=8 sex=1 age=47 union=0 ALquote=4 public=0 riskaversion=3) 


* ===========================================================================================
* 3.1.4 MAKE TABLE 1
* ===========================================================================================
estout trade1 fdi1 offshore1, cells(b(star fmt(%9.3f)) se(par fmt(%9.2f))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N)



* ******************************************************************************************************
* 3.2 LINK 2: GLOBALIZATION, ECONOMIC INSECURITY, AND DEMANDS FOR SOCIAL PROTECTION (TABLE 1 ctd.)
********************************************************************************************************
* ===========================================================================================
* 3.2.1 ECONOMIC INSECURITY
* ===========================================================================================
olog morestate safejob  skills income sex age union ALquote public  [pweight=w_regio]  if age<66
fitstat
estimates store s2

* Predicted Probabilities (Table 2, Link 2)
* ----------------------------------------
* Secure (Low Skill)
prvalue, x(safejob=0 skills=1 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 
* Insecure (Low Skill)
prvalue, x(safejob=1 skills=1 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 
* Secure (High Skill)
prvalue, x(safejob=0 skills=6 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 
* Insecure (High Skill)
prvalue, x(safejob=1 skills=6 income=8 sex=1 age=47 union=0 ALquote=4 public=0)  

* ===========================================================================================
* 3.2.2 TRADE
* ===========================================================================================
olog morestate  tradeexposure skills trade_skills income sex age union ALquote public [pweight=w_regio]  if age<66
fitstat
estimates store trade2

* Predicted Probabilities (Table 2, Link 2)
* ----------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(tradeexposure=0.3093797 skills=1 trade_skills=0.3093797 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 
* Low-Skill Sheltered (Low Skill, low exposure)
prvalue, x(tradeexposure=0 skills=1 trade_skills=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 
* High-Skill Sheltered (High Skill, low exposure)
prvalue, x(tradeexposure=0 skills=6 trade_skills=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(tradeexposure=0.3093797 skills=6 trade_skills=1.8562782 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 


* ===========================================================================================
* 3.2.3 FDI
* ===========================================================================================
olog morestate skills logfdi skill_fdi income sex age union ALquote public  [pweight=w_regio]  if age<66
fitstat
estimates store fdi2

* Predicted Probabilities (Table 2, Link 2)
* ----------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(logfdi=6.778512 skills=1 skill_fdi=6.778512 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 
* Intermediate I (Low Skill, low exposure)
prvalue, x(logfdi=0 skills=1 skill_fdi=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 
* Intermediate I (High Skill, low exposure)
prvalue, x(logfdi=0 skills=6 skill_fdi=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(logfdi=6.778512 skills=6 skill_fdi=40.671072 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 


* ===========================================================================================
* 3.2.4 OFFSHOREABILITY
* ===========================================================================================
olog morestate  offshore skills skill_offshore income sex age union ALquote public  [pweight=w_regio]  if age<66
fitstat
estimates store offshore2

* Predicted Probabilities (Table 2, Link 2)
* ----------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(offshore=100 skills=1 skill_offshore=100 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 
* Intermediate I (Low Skill, low exposure)
prvalue, x(offshore=0 skills=1 skill_offshore=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0) 
* Intermediate I (High Skill, low exposure)
prvalue, x(offshore=0 skills=6 skill_offshore=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(offshore=100 skills=6 skill_offshore=600 income=8 sex=1 age=47 union=0 ALquote=4 public=0 ) 

* ===========================================================================================
* 3.2.5 MAKE TABLE 1b
* ===========================================================================================
estout  s2 trade2 fdi2  offshore2, cells(b(star fmt(%9.3f)) se(par fmt(%9.2f))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N)



* ******************************************************************************************************
* 3.3 LINK 3: GLOBALIZATION, DEMANDS FOR SOCIAL PROTECTION, AND PARTY PREFERENCE (TABLE 3)
********************************************************************************************************
* ===========================================================================================
* 3.3.1 DEMANDS FOR SOCIAL PROTECTION
* ===========================================================================================
logit sp  morestate  skills  income sex age union ALquote public eu  [pweight=w_regio] if age<66
fitstat
estimates store m3

* Predicted Probabilities (Table 2, Link 3)
* ------------------------------------------
* Less State (Low Skill)
prvalue, x(morestate=1 skills=1 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 
* More State (Low Skill)
prvalue, x(morestate=10 skills=1 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 
* Less State (High Skill)
prvalue, x(morestate=1 skills=6 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 
* More State (High Skill)
prvalue, x(morestate=10 skills=6 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 


* ===========================================================================================
* 3.3.2 TRADE
* ===========================================================================================
logit sp  tradeexposure skills trade_skills income sex age union ALquote public eu [pweight=w_regio]  if age<66
fitstat
estimates store trade3

* Predicted Probabilities (Table 2, Link 3)
* ------------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(tradeexposure=0.3093797 skills=1 trade_skills=0.3093797 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 
* Low-Skill Sheltered (Low Skill, low exposure)
prvalue, x(tradeexposure=0 skills=1 trade_skills=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 
* High-Skill Sheltered (High Skill, low exposure)
prvalue, x(tradeexposure=0 skills=6 trade_skills=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(tradeexposure=0.3093797 skills=6 trade_skills=1.8562782 income=8 sex=1 age=47 union=0 ALquote=4 public=0 eu=3) 


* ===========================================================================================
* 3.3.3 FDI
* ===========================================================================================
logit sp   skills logfdi skill_fdi  income sex age union ALquote public eu  [pweight=w_regio] if age<66
fitstat
estimates store ffdi3

* Predicted Probabilities (Table 2, Link 3)
* ------------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(logfdi=6.778512 skills=1 skill_fdi=6.778512 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 
* Intermediate I (Low Skill, low exposure)
prvalue, x(logfdi=0 skills=1 skill_fdi=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 
* Intermediate I (High Skill, low exposure)
prvalue, x(logfdi=0 skills=6 skill_fdi=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(logfdi=6.778512 skills=6 skill_fdi=40.671072 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 


* ===========================================================================================
* 3.3.4 OFFSHOREABILITY
* ===========================================================================================
logit sp  offshore skills skill_offshore  income sex age union ALquote public eu [pweight=w_regio] if age<66
fitstat
estimates store foffshore3

* Predicted Probabilities (Table 2, Link 3)
* ------------------------------------------
* Globalization Loser (Low Skill, high exposure)
prvalue, x(offshore=100 skills=1 skill_offshore=100 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 
* Intermediate I (Low Skill, low exposure)
prvalue, x(offshore=0 skills=1 skill_offshore=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 
* Intermediate I (High Skill, low exposure)
prvalue, x(offshore=0 skills=6 skill_offshore=0 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 
* Globalization Winner (High Skill, high exposure)
prvalue, x(offshore=100 skills=6 skill_offshore=600 income=8 sex=1 age=47 union=0 ALquote=4 public=0  eu=3) 


* ===========================================================================================
* 3.3.5 MAKE TABLE 3
* ===========================================================================================
estout m3 trade3 ffdi3  foffshore3 , cells(b(star fmt(%9.3f)) se(par fmt(%9.2f))) style(fixed) starlevels(* 0.10 ** 0.05 *** 0.01) stats(N)



